# -*- coding: utf-8 -*-

from Products.CMFPlone.utils import base_hasattr
from Products.Five.browser import BrowserView

import re


class RichDescription(BrowserView):
    def description(self):
        """Description with html carriage return and bold"""
        description = ""
        if base_hasattr(self.context, "description"):
            description = self.context.description or ""
        # **strong**
        description = re.sub(r"\*\*([^\*\*]*)\*\*", r"<strong>\1</strong>", description)
        # <br/>
        description = "<br/>".join(description.split("\r\n"))
        return description



# -*- coding: utf-8 -*-

from plone import api
import logging

logger = logging.getLogger("imio.smartweb.common")
PROFILEID = "profile-imio.smartweb.common:default"


def reload_registry(context):
    portal_setup = api.portal.get_tool("portal_setup")
    portal_setup.runImportStepFromProfile(PROFILEID, "plone.app.registry")


def reload_actions(context):
    portal_setup = api.portal.get_tool("portal_setup")
    portal_setup.runImportStepFromProfile(PROFILEID, "actions")
